@@ -1,3 +1,4 @@
+import pandas as pd
 from woodwork.logical_types import Boolean, BooleanNullable
 
 
@@ -169,10 +170,18 @@ def remove_highly_correlated_features(
         more_complex_name = columns_to_check[i]
         more_complex_col = fm_to_check[more_complex_name]
 
+        # Convert boolean column to be float64
+        if pd.api.types.is_bool_dtype(more_complex_col):
+            more_complex_col = more_complex_col.astype("float64")
+
         for j in range(i - 1, -1, -1):
             less_complex_name = columns_to_check[j]
             less_complex_col = fm_to_check[less_complex_name]
 
+            # Convert boolean column to be float64
+            if pd.api.types.is_bool_dtype(less_complex_col):
+                less_complex_col = less_complex_col.astype("float64")
+
             if abs(more_complex_col.corr(less_complex_col)) >= pct_corr_threshold:
                 dropped.add(more_complex_name)
                 break
