@@ -25,7 +25,8 @@ from woodwork.logical_types import (
     SubRegionCode,
 )
 
-import featuretools as ft
+from featuretools import Relationship
+from featuretools.demo import load_retail
 from featuretools.entityset import EntitySet
 from featuretools.entityset.entityset import LTI_COLUMN_NAME, WW_SCHEMA_KEY
 from featuretools.tests.testing_utils import get_df_tags, to_pandas
@@ -125,7 +126,7 @@ def test_add_relationships_convert_type(es):
         assert parent_df.ww.index == r._parent_column_name
         assert "foreign_key" in r.child_column.ww.semantic_tags
         assert str(parent_df[r._parent_column_name].dtype) == str(
-            child_df[r._child_column_name].dtype
+            child_df[r._child_column_name].dtype,
         )
 
 
@@ -277,7 +278,7 @@ def test_add_relationship_errors_child_v_index(es):
 
 
 def test_add_relationship_empty_child_convert_dtype(es):
-    relationship = ft.Relationship(es, "sessions", "id", "log", "session_id")
+    relationship = Relationship(es, "sessions", "id", "log", "session_id")
     empty_log_df = pd.DataFrame(columns=es["log"].columns)
     if es.dataframe_type == Library.DASK.value:
         empty_log_df = dd.from_pandas(empty_log_df, npartitions=2)
@@ -298,19 +299,19 @@ def test_add_relationship_empty_child_convert_dtype(es):
 
 
 def test_add_relationship_with_relationship_object(es):
-    relationship = ft.Relationship(es, "sessions", "id", "log", "session_id")
+    relationship = Relationship(es, "sessions", "id", "log", "session_id")
     es.add_relationship(relationship=relationship)
     assert relationship in es.relationships
 
 
 def test_add_relationships_with_relationship_object(es):
-    relationships = [ft.Relationship(es, "sessions", "id", "log", "session_id")]
+    relationships = [Relationship(es, "sessions", "id", "log", "session_id")]
     es.add_relationships(relationships)
     assert relationships[0] in es.relationships
 
 
 def test_add_relationship_error(es):
-    relationship = ft.Relationship(es, "sessions", "id", "log", "session_id")
+    relationship = Relationship(es, "sessions", "id", "log", "session_id")
     error_message = (
         "Cannot specify dataframe and column name values and also supply a Relationship"
     )
@@ -324,10 +325,10 @@ def test_query_by_values_returns_rows_in_given_order():
             "id": [1, 2, 3, 4, 5],
             "value": ["a", "c", "b", "a", "a"],
             "time": [1000, 2000, 3000, 4000, 5000],
-        }
+        },
     )
 
-    es = ft.EntitySet()
+    es = EntitySet()
     es = es.add_dataframe(
         dataframe=data,
         dataframe_name="test",
@@ -434,7 +435,9 @@ def test_query_by_column_with_lti_and_training_window(es):
 
 def test_query_by_indexed_column(es):
     df = es.query_by_values(
-        dataframe_name="log", instance_vals=["taco clock"], column_name="product_id"
+        dataframe_name="log",
+        instance_vals=["taco clock"],
+        column_name="product_id",
     )
     # Account for different ordering between pandas and dask/spark
     df = to_pandas(df).reset_index(drop=True).sort_values("id")
@@ -467,13 +470,17 @@ def test_check_columns_and_dataframe(df):
     logical_types = {"id": Integer, "category": Categorical}
     es = EntitySet(id="test")
     es.add_dataframe(
-        df, dataframe_name="test_dataframe", index="id", logical_types=logical_types
+        df,
+        dataframe_name="test_dataframe",
+        index="id",
+        logical_types=logical_types,
     )
     assert isinstance(
-        es.dataframe_dict["test_dataframe"].ww.logical_types["category"], Categorical
+        es.dataframe_dict["test_dataframe"].ww.logical_types["category"],
+        Categorical,
     )
     assert es.dataframe_dict["test_dataframe"].ww.semantic_tags["category"] == {
-        "category"
+        "category",
     }
 
 
@@ -576,7 +583,7 @@ def test_extra_column_type(df):
     logical_types = {"id": Integer, "category": Categorical, "category2": Categorical}
 
     error_text = re.escape(
-        "logical_types contains columns that are not present in dataframe: ['category2']"
+        "logical_types contains columns that are not present in dataframe: ['category2']",
     )
     with pytest.raises(LookupError, match=error_text):
         es = EntitySet(id="test")
@@ -671,7 +678,7 @@ def test_unknown_index(df3):
         )
     assert es["test_dataframe"].ww.index == "id"
     assert list(to_pandas(es["test_dataframe"]["id"], sort_index=True)) == list(
-        range(3)
+        range(3),
     )
 
 
@@ -711,7 +718,7 @@ def pd_df4():
             "category_int": [1, 2, 3],
             "ints": ["1", "2", "3"],
             "floats": ["1", "2", "3.0"],
-        }
+        },
     )
     df["category_int"] = df["category_int"].astype("category")
     return df
@@ -853,7 +860,7 @@ def pd_datetime2():
     actual = pd.Timestamp("Jan 2, 2011")
     time_strs = [actual.strftime(datetime_format)] * 3
     return pd.DataFrame(
-        {"id": [0, 1, 2], "time_format": time_strs, "time_no_format": time_strs}
+        {"id": [0, 1, 2], "time_format": time_strs, "time_no_format": time_strs},
     )
 
 
@@ -926,7 +933,7 @@ def test_dataframe_init(es):
             "time": [datetime(2011, 4, 9, 10, 31, 3 * i) for i in range(3)],
             "category": ["a", "b", "a"],
             "number": [4, 5, 6],
-        }
+        },
     )
     if es.dataframe_type == Library.DASK.value:
         df = dd.from_pandas(df, npartitions=2)
@@ -991,7 +998,7 @@ def test_nonstr_column_names(bad_df):
     if isinstance(bad_df, dd.DataFrame):
         pytest.xfail("Dask DataFrames cannot handle integer column names")
 
-    es = ft.EntitySet(id="Failure")
+    es = EntitySet(id="Failure")
     error_text = r"All column names must be strings \(Columns \[3\] are not strings\)"
     with pytest.raises(ValueError, match=error_text):
         es.add_dataframe(dataframe_name="str_cols", dataframe=bad_df, index="a")
@@ -1008,11 +1015,12 @@ def test_sort_time_id():
             "transaction_time": pd.date_range(start="10:00", periods=6, freq="10s")[
                 ::-1
             ],
-        }
+        },
     )
 
     es = EntitySet(
-        "test", dataframes={"t": (transactions_df.copy(), "id", "transaction_time")}
+        "test",
+        dataframes={"t": (transactions_df.copy(), "id", "transaction_time")},
     )
     assert es["t"] is not transactions_df
     times = list(es["t"].transaction_time)
@@ -1031,7 +1039,7 @@ def test_already_sorted_parameter():
                 datetime(2015, 4, 8),
                 datetime(2016, 4, 9),
             ],
-        }
+        },
     )
 
     es = EntitySet(id="test")
@@ -1255,7 +1263,7 @@ def pd_transactions_df():
             "card_id": [1, 2, 1, 3, 4, 5],
             "transaction_time": [10, 12, 13, 20, 21, 20],
             "fraud": [True, False, False, False, True, True],
-        }
+        },
     )
 
 
@@ -1271,7 +1279,7 @@ def spark_transactions_df(pd_transactions_df):
 
 
 @pytest.fixture(
-    params=["pd_transactions_df", "dd_transactions_df", "spark_transactions_df"]
+    params=["pd_transactions_df", "dd_transactions_df", "spark_transactions_df"],
 )
 def transactions_df(request):
     return request.getfixturevalue(request.param)
@@ -1320,10 +1328,10 @@ def test_sets_time_when_adding_dataframe(transactions_df):
                 datetime(2006, 3, 20),
                 datetime(2011, 11, 11),
             ],
-        }
+        },
     )
     accounts_df_string = pd.DataFrame(
-        {"id": [3, 4, 5], "signup_date": ["element", "exporting", "editable"]}
+        {"id": [3, 4, 5], "signup_date": ["element", "exporting", "editable"]},
     )
     if isinstance(transactions_df, dd.DataFrame):
         accounts_df = dd.from_pandas(accounts_df, npartitions=2)
@@ -1444,7 +1452,7 @@ def test_checks_time_type_setting_secondary_time_index(es):
             "transaction_city": ["City A"] * 6,
             "transaction_date": [datetime(1989, 2, i) for i in range(1, 7)],
             "fraud": [True, False, False, False, True, True],
-        }
+        },
     )
     dataframes = {
         "cards": (cards_df, "id"),
@@ -1487,13 +1495,19 @@ def test_normalize_dataframe(es):
     error_text = "'additional_columns' must be a list, but received type.*"
     with pytest.raises(TypeError, match=error_text):
         es.normalize_dataframe(
-            "sessions", "device_types", "device_type", additional_columns="log"
+            "sessions",
+            "device_types",
+            "device_type",
+            additional_columns="log",
         )
 
     error_text = "'copy_columns' must be a list, but received type.*"
     with pytest.raises(TypeError, match=error_text):
         es.normalize_dataframe(
-            "sessions", "device_types", "device_type", copy_columns="log"
+            "sessions",
+            "device_types",
+            "device_type",
+            copy_columns="log",
         )
 
     es.normalize_dataframe(
@@ -1594,15 +1608,15 @@ def pd_normalize_es():
                 datetime(2020, 5, 1),
                 datetime(2020, 4, 22),
             ],
-        }
+        },
     )
-    es = ft.EntitySet("es")
+    es = EntitySet("es")
     return es.add_dataframe(dataframe_name="data", dataframe=df, index="id")
 
 
 @pytest.fixture
 def dd_normalize_es(pd_normalize_es):
-    es = ft.EntitySet(id=pd_normalize_es.id)
+    es = EntitySet(id=pd_normalize_es.id)
     dd_df = dd.from_pandas(pd_normalize_es["data"], npartitions=2)
     dd_df.ww.init(schema=pd_normalize_es["data"].ww.schema)
 
@@ -1613,7 +1627,7 @@ def dd_normalize_es(pd_normalize_es):
 @pytest.fixture
 def spark_normalize_es(pd_normalize_es):
     ps = pytest.importorskip("pyspark.pandas", reason="Spark not installed, skipping")
-    es = ft.EntitySet(id=pd_normalize_es.id)
+    es = EntitySet(id=pd_normalize_es.id)
     spark_df = ps.from_pandas(pd_normalize_es["data"])
     spark_df.ww.init(schema=pd_normalize_es["data"].ww.schema)
     es.add_dataframe(dataframe=spark_df)
@@ -1673,9 +1687,9 @@ def test_normalize_dataframe_copies_logical_types(es):
     es["log"].ww.set_types(
         logical_types={
             "value": Ordinal(
-                order=[0.0, 1.0, 2.0, 3.0, 5.0, 7.0, 10.0, 14.0, 15.0, 20.0]
-            )
-        }
+                order=[0.0, 1.0, 2.0, 3.0, 5.0, 7.0, 10.0, 14.0, 15.0, 20.0],
+            ),
+        },
     )
 
     assert isinstance(es["log"].ww.logical_types["value"], Ordinal)
@@ -1715,7 +1729,10 @@ def test_make_time_index_keeps_original_sorting():
     df = pd.DataFrame.from_dict(trips)
     es = EntitySet("flights")
     es.add_dataframe(
-        dataframe=df, dataframe_name="trips", index="trip_id", time_index="flight_time"
+        dataframe=df,
+        dataframe_name="trips",
+        index="trip_id",
+        time_index="flight_time",
     )
     assert (es["trips"]["trip_id"] == order).all()
     es.normalize_dataframe(
@@ -1750,9 +1767,9 @@ def test_normalize_dataframe_same_index(es):
             "id": [1, 2, 3],
             "transaction_time": pd.date_range(start="10:00", periods=3, freq="10s"),
             "first_df_time": [1, 2, 3],
-        }
+        },
     )
-    es = ft.EntitySet("example")
+    es = EntitySet("example")
     es.add_dataframe(
         dataframe_name="df",
         index="id",
@@ -1784,7 +1801,7 @@ def test_secondary_time_index(es):
     assert isinstance(es["values"].ww.logical_types["second_ti"], Datetime)
     assert es["values"].ww.semantic_tags["second_ti"] == set()
     assert es["values"].ww.metadata["secondary_time_index"] == {
-        "second_ti": ["comments", "second_ti"]
+        "second_ti": ["comments", "second_ti"],
     }
 
 
@@ -1798,22 +1815,22 @@ def test_sizeof(es):
 
 
 def test_construct_without_id():
-    assert ft.EntitySet().id is None
+    assert EntitySet().id is None
 
 
 def test_repr_without_id():
     match = "Entityset: None\n  DataFrames:\n  Relationships:\n    No relationships"
-    assert repr(ft.EntitySet()) == match
+    assert repr(EntitySet()) == match
 
 
 def test_getitem_without_id():
     error_text = "DataFrame test does not exist in entity set"
     with pytest.raises(KeyError, match=error_text):
-        ft.EntitySet()["test"]
+        EntitySet()["test"]
 
 
 def test_metadata_without_id():
-    es = ft.EntitySet()
+    es = EntitySet()
     assert es.metadata.id is None
 
 
@@ -1868,7 +1885,7 @@ def pd_index_df():
             "id": [1, 2, 3, 4, 5, 6],
             "transaction_time": pd.date_range(start="10:00", periods=6, freq="10s"),
             "first_dataframe_time": [1, 2, 3, 5, 6, 6],
-        }
+        },
     )
 
 
@@ -1898,7 +1915,7 @@ def test_same_index_values(index_df):
     else:
         logical_types = None
 
-    es = ft.EntitySet("example")
+    es = EntitySet("example")
 
     error_text = (
         '"id" is already set as the index. An index cannot also be the time index.'
@@ -1948,10 +1965,10 @@ def test_use_time_index(index_df):
         bad_semantic_tags = {"transaction_time": "time_index"}
         logical_types = None
 
-    es = ft.EntitySet()
+    es = EntitySet()
 
     error_text = re.escape(
-        "Cannot add 'time_index' tag directly for column transaction_time. To set a column as the time index, use DataFrame.ww.set_time_index() instead."
+        "Cannot add 'time_index' tag directly for column transaction_time. To set a column as the time index, use DataFrame.ww.set_time_index() instead.",
     )
     with pytest.raises(ValueError, match=error_text):
         es.add_dataframe(
@@ -1999,7 +2016,7 @@ def test_normalize_with_numeric_time_index(int_es):
 def test_normalize_with_invalid_time_index(es):
     if es.dataframe_type == Library.DASK.value:
         pytest.skip(
-            "Woodwork raises different error with Dask. Remove this skip once WW is updated."
+            "Woodwork raises different error with Dask. Remove this skip once WW is updated.",
         )
     error_text = "Time index column must contain datetime or numeric values"
     with pytest.raises(TypeError, match=error_text):
@@ -2021,7 +2038,7 @@ def test_entityset_init():
             "transaction_time": [10, 12, 13, 20, 21, 20],
             "upgrade_date": [51, 23, 45, 12, 22, 53],
             "fraud": [True, False, False, False, True, True],
-        }
+        },
     )
     logical_types = {"fraud": "boolean", "card_id": "integer"}
     dataframes = {
@@ -2036,12 +2053,10 @@ def test_entityset_init():
         ),
     }
     relationships = [("cards", "id", "transactions", "card_id")]
-    es = ft.EntitySet(
-        id="fraud_data", dataframes=dataframes, relationships=relationships
-    )
+    es = EntitySet(id="fraud_data", dataframes=dataframes, relationships=relationships)
     assert es["transactions"].ww.index == "id"
     assert es["transactions"].ww.time_index == "transaction_time"
-    es_copy = ft.EntitySet(id="fraud_data")
+    es_copy = EntitySet(id="fraud_data")
     es_copy.add_dataframe(dataframe_name="cards", dataframe=cards_df.copy(), index="id")
     es_copy.add_dataframe(
         dataframe_name="transactions",
@@ -2122,7 +2137,7 @@ def test_add_interesting_values_multiple_dataframes(pd_es):
 
 
 def test_add_interesting_values_verbose_output(caplog):
-    es = ft.demo.load_retail(nrows=200)
+    es = load_retail(nrows=200)
     es["order_products"].ww.set_types({"quantity": "Categorical"})
     es["orders"].ww.set_types({"country": "Categorical"})
     logger = logging.getLogger("featuretools")
@@ -2420,13 +2435,14 @@ def test_deepcopy_entityset_featuretools_changes(es):
     assert copied_es is not es
 
     copied_es.set_secondary_time_index(
-        "customers", {"upgrade_date": ["engagement_level"]}
+        "customers",
+        {"upgrade_date": ["engagement_level"]},
     )
     assert copied_es["customers"].ww.metadata["secondary_time_index"] == {
-        "upgrade_date": ["engagement_level", "upgrade_date"]
+        "upgrade_date": ["engagement_level", "upgrade_date"],
     }
     assert es["customers"].ww.metadata["secondary_time_index"] == {
-        "cancel_date": ["cancel_reason", "cancel_date"]
+        "cancel_date": ["cancel_reason", "cancel_date"],
     }
 
 
@@ -2452,7 +2468,7 @@ def test_pd_es_pickling(pd_es):
 
 
 def test_empty_es_pickling():
-    es = ft.EntitySet(id="empty")
+    es = EntitySet(id="empty")
     pkl = pickle.dumps(es)
     unpickled = pickle.loads(pkl)
 
@@ -2461,7 +2477,7 @@ def test_empty_es_pickling():
 
 @patch("featuretools.EntitySet.add_dataframe")
 def test_setitem(add_dataframe):
-    es = ft.EntitySet()
+    es = EntitySet()
     df = pd.DataFrame()
     es["new_df"] = df
     assert add_dataframe.called
@@ -2470,7 +2486,9 @@ def test_setitem(add_dataframe):
 
 def test_latlong_nan_normalization(latlong_df):
     latlong_df.ww.init(
-        name="latLong", index="idx", logical_types={"latLong": "LatLong"}
+        name="latLong",
+        index="idx",
+        logical_types={"latLong": "LatLong"},
     )
 
     dataframes = {"latLong": (latlong_df,)}
@@ -2482,7 +2500,7 @@ def test_latlong_nan_normalization(latlong_df):
     normalized_df = to_pandas(es["latLong"], sort_index=True)
 
     expected_df = pd.DataFrame(
-        {"idx": [0, 1, 2], "latLong": [(np.nan, np.nan), (1, 2), (np.nan, np.nan)]}
+        {"idx": [0, 1, 2], "latLong": [(np.nan, np.nan), (1, 2), (np.nan, np.nan)]},
     )
 
     pd.testing.assert_frame_equal(normalized_df, expected_df)
@@ -2490,7 +2508,9 @@ def test_latlong_nan_normalization(latlong_df):
 
 def test_latlong_nan_normalization_add_dataframe(latlong_df):
     latlong_df.ww.init(
-        name="latLong", index="idx", logical_types={"latLong": "LatLong"}
+        name="latLong",
+        index="idx",
+        logical_types={"latLong": "LatLong"},
     )
 
     es = EntitySet("latlong-test")
@@ -2500,7 +2520,7 @@ def test_latlong_nan_normalization_add_dataframe(latlong_df):
     normalized_df = to_pandas(es["latLong"], sort_index=True)
 
     expected_df = pd.DataFrame(
-        {"idx": [0, 1, 2], "latLong": [(np.nan, np.nan), (1, 2), (np.nan, np.nan)]}
+        {"idx": [0, 1, 2], "latLong": [(np.nan, np.nan), (1, 2), (np.nan, np.nan)]},
     )
 
     pd.testing.assert_frame_equal(normalized_df, expected_df)
