@@ -5,7 +5,7 @@ import pytest
 from featuretools.utils import (
     get_featuretools_root,
     get_installed_packages,
-    get_sys_info
+    get_sys_info,
 )
 
 
@@ -16,9 +16,18 @@ def this_dir():
 
 def test_sys_info():
     sys_info = get_sys_info()
-    info_keys = ["python", "python-bits", "OS",
-                 "OS-release", "machine", "processor",
-                 "byteorder", "LC_ALL", "LANG", "LOCALE"]
+    info_keys = [
+        "python",
+        "python-bits",
+        "OS",
+        "OS-release",
+        "machine",
+        "processor",
+        "byteorder",
+        "LC_ALL",
+        "LANG",
+        "LOCALE",
+    ]
     found_keys = [k for k, _ in sys_info]
     assert set(info_keys).issubset(found_keys)
 
@@ -27,14 +36,22 @@ def test_installed_packages():
     installed_packages = get_installed_packages()
     # Per PEP 426, package names are case insensitive
     # Underscore and hyphen are equivalent
-    installed_set = {name.lower().replace('-', '_')
-                     for name in installed_packages.keys()}
-    requirements = ["pandas", "numpy", "tqdm",
-                    "cloudpickle", "dask", "distributed",
-                    "psutil", "click"]
+    installed_set = {
+        name.lower().replace("-", "_") for name in installed_packages.keys()
+    }
+    requirements = [
+        "pandas",
+        "numpy",
+        "tqdm",
+        "cloudpickle",
+        "dask",
+        "distributed",
+        "psutil",
+        "click",
+    ]
     assert set(requirements).issubset(installed_set)
 
 
 def test_get_featuretools_root(this_dir):
-    root = os.path.abspath(os.path.join(this_dir, '..', ".."))
+    root = os.path.abspath(os.path.join(this_dir, "..", ".."))
     assert get_featuretools_root() == root
